==> restful-api-framework-2.0.0.tgz: package/source/core.ts <==
import { ServerOptions, Route, Request, Response } from './types';
import { RequestHandler } from './requestHandler';
import { Server, createServer } from 'http';

import * as Errors from './errors';

const SECONDS_IN_ONE_DAY = 86400;

let self: ApiServer;

export class ApiServer {

    private server: Server;
    public routes: Route[];
    public options: ServerOptions;
    public middleware: Function[] = [];

    constructor(options: ServerOptions) {
        this.options = options;

        self = this;
    }

    private setHeaders(res: Response): void {
        let cors = this.options.cors;

        res.setHeader('Access-Content-Allow-Origin', cors.origin || '*');
        res.setHeader('Access-Control-Max-Age', cors.maxAge.toString() || SECONDS_IN_ONE_DAY.toString());
        res.setHeader('Access-Control-Allow-Credentials', (cors.credentials || false) === true ? 'true' : 'false');

        res.removeHeader('X-Powered-By');
        res.setHeader('Server', this.options.serverName || 'APIserver');

        if (this.options.enableSecurityHeaders) {
            const headers = {
                "X-Content-Type-Options": "nosniff",
                "X-Frame-Options": "SAMEORIGIN",
                "X-Xss-Protection": "1; mode=block"
            };

            for (let i in headers) {
                res.setHeader(i, headers[i]);
            }
        }
    }

    private responseFunctions(response: Response): void {

        response.status = (code: number) => {
            response.statusCode = code;
        };

        // Send response
        response.send = (
            data: string | object | Errors.ApiError, status: number = 200) => {

            let responseData: any = {
                content: data,
                contentType: 'text/plain; charset=utf-8'
            };

            if (typeof data === 'object') {
                responseData.contentType = 'application/json; charset=utf-8';

                if(data instanceof Errors.ApiError) {
                    response.writeHead(data.status, {
                        'Content-Type': responseData.contentType
                    });
                    
                    response.write(this.responseWithError(data));
                    response.end();

                    return;
                }

                responseData.content = JSON.stringify(data);
            }

            response.writeHead(status, {
                'Content-Type': responseData.contentType
            });

            response.write(responseData.content);
            response.end();
        };
    }

    private responseWithError(error: Errors.ApiError) {
        return JSON.stringify({
            code: error.status,
            message: error.message,
            description: error.description
        });
    }
    
    handler (request: Request, response: Response): RequestHandler {
        request.params = {};
        request.body = {};

        self.setHeaders(response);     
        self.responseFunctions(response);   

        return RequestHandler.handle(self, request, response);
    }

    // For routers
    public register (routes: Route[]) {
        this.routes = routes;
    }

    // For global request middleware
    public use (middleware: Function) {
        this.middleware.push(middleware);
    }

    // Logging
    public enableLogger () { }

    // Start
    public run() {
        this.server = createServer(this.handler);

        this.server.listen(
            this.options.port,
            this.options.hostname ? this.options.hostname : 'localhost'
        );
    }
}

==> restful-api-framework-2.0.2.tgz: package/source/core.ts <==
import { ServerOptions, Route, Request, Response } from './types';
import { RequestHandler } from './requestHandler';
import { Server, createServer } from 'http';

import * as Errors from './errors';

const SECONDS_IN_ONE_DAY = 86400;

let self: ApiServer;

export class ApiServer {

    private server: Server;
    public routes: Route[];
    public options: ServerOptions;
    public middleware: Function[] = [];

    constructor(options: ServerOptions) {
        this.options = options;

        self = this;
    }

    private setHeaders(res: Response): void {
        let cors = this.options.cors;

        res.setHeader('Access-Control-Allow-Origin', cors.origin || '*');
        res.setHeader('Access-Control-Max-Age', cors.maxAge.toString() || SECONDS_IN_ONE_DAY.toString());
        res.setHeader('Access-Control-Allow-Credentials', (cors.credentials || false) === true ? 'true' : 'false');

        res.removeHeader('X-Powered-By');
        res.setHeader('Server', this.options.serverName || 'APIserver');

        if (this.options.enableSecurityHeaders) {
            const headers = {
                "X-Content-Type-Options": "nosniff",
                "X-Frame-Options": "SAMEORIGIN",
                "X-Xss-Protection": "1; mode=block"
            };

            for (let i in headers) {
                res.setHeader(i, headers[i]);
            }
        }
    }

    private responseFunctions(response: Response): void {

        response.status = (code: number) => {
            response.statusCode = code;
        };

        // Send response
        response.send = (
            data: string | object | Errors.ApiError, status: number = 200) => {

            let responseData: any = {
                content: data,
                contentType: 'text/plain; charset=utf-8'
            };

            if (typeof data === 'object') {
                responseData.contentType = 'application/json; charset=utf-8';

                if(data instanceof Errors.ApiError) {
                    response.writeHead(data.status, {
                        'Content-Type': responseData.contentType
                    });
                    
                    response.write(this.responseWithError(data));
                    response.end();

                    return;
                }

                responseData.content = JSON.stringify(data);
            }

            response.writeHead(status, {
                'Content-Type': responseData.contentType
            });

            response.write(responseData.content);
            response.end();
        };
    }

    private responseWithError(error: Errors.ApiError) {
        return JSON.stringify({
            code: error.status,
            message: error.message,
            description: error.description
        });
    }
    
    handler (request: Request, response: Response): RequestHandler {
        request.params = {};
        request.body = {};

        self.setHeaders(response);     
        self.responseFunctions(response);   

        return RequestHandler.handle(self, request, response);
    }

    // For routers
    public register (routes: Route[]) {
        this.routes = routes;
    }

    // For global request middleware
    public use (middleware: Function) {
        this.middleware.push(middleware);
    }

    // Start
    public run() {
        this.server = createServer(this.handler);

        this.server.listen(
            this.options.port,
            this.options.hostname || 'localhost'
        );
    }
}
